@@ -260,7 +260,7 @@ INTERNALERROR_QUERYRESOURCESPECFAILED = 'InternalError.QueryResourceSpecFailed'
 # 查询子网信息失败。
 INTERNALERROR_QUERYSUBNETINFOFAILED = 'InternalError.QuerySubnetInfoFailed'
 
-# 查询用户临时秘钥失败
+# 查询用户临时密钥失败
 INTERNALERROR_QUERYUSERTMPCREDENTIALFAILED = 'InternalError.QueryUserTMPCredentialFailed'
 
 # 查询vpc信息失败
@@ -344,6 +344,9 @@ INVALIDPARAMETERVALUE_DCDATASETTYPE = 'InvalidParameterValue.DCDatasetType'
 # 不支持的过滤参数。
 INVALIDPARAMETERVALUE_DCFILTERVALUES = 'InvalidParameterValue.DCFilterValues'
 
+# 数据配置数量超过最大限制
+INVALIDPARAMETERVALUE_DATACONFIGNUMLIMITEXCEEDED = 'InvalidParameterValue.DataConfigNumLimitExceeded'
+
 # 数据集不存在
 INVALIDPARAMETERVALUE_DATASETNOTEXIST = 'InvalidParameterValue.DatasetNotExist'
 
@@ -425,6 +428,9 @@ INVALIDPARAMETERVALUE_UNSUPPORTEDDATACONFIG = 'InvalidParameterValue.Unsupported
 # 不支持使用GooseFS实例
 INVALIDPARAMETERVALUE_UNSUPPORTEDGOOSEFSCONFIG = 'InvalidParameterValue.UnsupportedGooseFSConfig'
 
+# 不支持同一实例挂载多个CBS存储
+INVALIDPARAMETERVALUE_UNSUPPORTEDMULTICBSSTORAGE = 'InvalidParameterValue.UnsupportedMultiCBSStorage'
+
 # Notebook卷大小只能增加，如需减小容量请重新创建实例。
 INVALIDPARAMETERVALUE_VOLUMESHRINKNOTALLOW = 'InvalidParameterValue.VolumeShrinkNotAllow'
 
